==> tdm_2.0.0.tar.gz: tdm/R/all.Oxtirss.R <==
all.Oxtirss<-function(){
     cat("-----------------------------------------------------------\n")
     cat("    --Oxtriphylline IR input data information--            \n")
     note_for_Theirss_input()
     cat("-----------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     OxtirSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)","ts (hr)","c (mg/L)"),value=c(0))                   
     OxtirSSpar<-edit(OxtirSSpar)                                                                                                                   
     OxtirSSpar<-ycheck(OxtirSSpar)           
     cat("\n")                                                                                                         
     Oxtir.ss(OxtirSSpar[9,2],OxtirSSpar[7,2],OxtirSSpar[8,2],OxtirSSpar[6,2],OxtirSSpar[3,2],OxtirSSpar[2,2],OxtirSSpar[5,2],OxtirSSpar[1,2],OxtirSSpar[4,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("-----------------------------------------------------------\n")
     cat("    --Oxtriphylline IR output data information--           \n")
     note_for_Theirss_output()
     cat("-----------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n") 
     C<-TheIRsscpr(0.65,OxtirSSpar[6,2],OxtirSSpar[7,2],OxtirSSpar[8,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     output1<-coutput
     show(coutput)
     r=log(1.85-(samplesStats("cl_F")/samplesStats("v_F")))/(1.85-(samplesStats("cl_F")/samplesStats("v_F")))
     C<-TheIRsscpr(0.65,OxtirSSpar[6,2],OxtirSSpar[7,2],r)
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cpss_pr (mg/L)")
     output2<-coutput
     show(coutput)
     C<-TheIRsscpr(0.65,OxtirSSpar[6,2],OxtirSSpar[7,2],OxtirSSpar[7,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output3<-coutput
     show(coutput)     
     cat("\n")  
     Oxtir.more()                                     
}

==> tdm_2.2.6.tar.gz: tdm/R/all.Oxtirss.R <==
all.Oxtirss<-function(){
     cat("-----------------------------------------------------------\n")
     cat("    --Oxtriphylline IR input data information--            \n")
     note_for_Theirss_input()
     cat("-----------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     OxtirSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)","ts (hr)","c (mg/L)"),value=c(0))                   
     OxtirSSpar<-edit(OxtirSSpar)                                                                                                                   
##     OxtirSSpar<-ycheck(OxtirSSpar)           
     cat("\n")                                                                                                         
     Oxtir.ss(OxtirSSpar[9,2],OxtirSSpar[7,2],OxtirSSpar[8,2],OxtirSSpar[6,2],OxtirSSpar[3,2],OxtirSSpar[2,2],OxtirSSpar[5,2],OxtirSSpar[1,2],OxtirSSpar[4,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("-----------------------------------------------------------\n")
     cat("    --Oxtriphylline IR output data information--           \n")
     note_for_Theirss_output()
     cat("-----------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n") 
     C<-TheIRsscpr(0.65,OxtirSSpar[6,2],OxtirSSpar[7,2],OxtirSSpar[8,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     output1<-coutput
     show(coutput)
     r=log(1.85-(samplesStats("cl_F")/samplesStats("v_F")))/(1.85-(samplesStats("cl_F")/samplesStats("v_F")))
     C<-TheIRsscpr(0.65,OxtirSSpar[6,2],OxtirSSpar[7,2],r)
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cpss_pr (mg/L)")
     output2<-coutput
     show(coutput)
     C<-TheIRsscpr(0.65,OxtirSSpar[6,2],OxtirSSpar[7,2],OxtirSSpar[7,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output3<-coutput
     show(coutput)     
     cat("\n")  
     Oxtir.more()                                     
}
